@@ -1,3 +1,9 @@
+if (arch = RbConfig::CONFIG["arch"]) == "powerpc64le-linux-gnu"
+  puts "I: skipping tests on #{arch}"
+  exit(0)
+end
+
+
 ENV['TZ']="Europe/Paris"
 SKIPPED_TESTS = [
   './test/./test_serializer.rb',
@@ -8,7 +14,8 @@ SKIPPED_TESTS = [
 ]
 
 success=true
-Dir.glob("./test/{isolated,.}/test*.rb").each do |f|
+#Dir.glob("./test/{isolated,.}/test*.rb").each do |f|
+["tests", "tests_mimic", "tests_mimic_addition"].map {|s| "test/#{s}.rb"}.each do |f|
   # we'd like to not have rails in Build-Depends, but this means we can't test the rails integration.
   next if SKIPPED_TESTS.include?(f)
   puts "-------- running #{f} test ------- "
